.. _ref-configuration:

Configuration
=============

This page describes the format of the configuration file that can be used to initialize a ``MultiAnalyzer`` object.

You can download the complete validation schema :download:`here <../../src/blueetl/schemas/analysis_config.yaml>`.


Schema
------

.. jsonschema:: ../../src/blueetl/schemas/analysis_config.yaml
    :lift_definitions:
    :auto_target:
    :auto_reference:


Examples
--------

Example 01
~~~~~~~~~~

.. literalinclude:: ../../tests/functional/data/sonata/config/analysis_config_01.yaml
   :language: yaml
   :emphasize-lines: 2

Example 02
~~~~~~~~~~

.. literalinclude:: ../../tests/functional/data/sonata/config/analysis_config_02.yaml
   :language: yaml
   :emphasize-lines: 2

Example 03
~~~~~~~~~~

.. literalinclude:: ../../tests/functional/data/sonata/config/analysis_config_03.yaml
   :language: yaml
   :emphasize-lines: 2

Example 04
~~~~~~~~~~

.. literalinclude:: ../../tests/functional/data/sonata/config/analysis_config_04.yaml
   :language: yaml
   :emphasize-lines: 2

Example 05
~~~~~~~~~~

.. literalinclude:: ../../tests/functional/data/sonata/config/analysis_config_05.yaml
   :language: yaml
   :emphasize-lines: 2

Example 06
~~~~~~~~~~

.. literalinclude:: ../../tests/functional/data/sonata/config/analysis_config_06.yaml
   :language: yaml
   :emphasize-lines: 2

Example 07
~~~~~~~~~~

.. literalinclude:: ../../tests/functional/data/sonata/config/analysis_config_07.yaml
   :language: yaml
   :emphasize-lines: 2

Example 08
~~~~~~~~~~

.. literalinclude:: ../../tests/functional/data/sonata/config/analysis_config_08.yaml
   :language: yaml
   :emphasize-lines: 2

Example 09
~~~~~~~~~~

.. literalinclude:: ../../tests/functional/data/sonata/config/analysis_config_09.yaml
   :language: yaml
   :emphasize-lines: 2

Example 10
~~~~~~~~~~

.. literalinclude:: ../../tests/functional/data/sonata/config/analysis_config_10.yaml
   :language: yaml
   :emphasize-lines: 2

Example 11
~~~~~~~~~~

.. literalinclude:: ../../tests/functional/data/sonata/config/analysis_config_11.yaml
   :language: yaml
   :emphasize-lines: 2

Example 12
~~~~~~~~~~

.. literalinclude:: ../../tests/functional/data/sonata/config/analysis_config_12.yaml
   :language: yaml
   :emphasize-lines: 2-3
